Class: Google::Apis::WorkstationsV1beta::CloudWorkstationsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::WorkstationsV1beta::CloudWorkstationsService
- Defined in:
- lib/google/apis/workstations_v1beta/service.rb
Overview
Cloud Workstations API
Allows administrators to create managed developer environments in the cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://workstations.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation cluster.
-
#create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation configuration.
-
#create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty
Deletes a long-running operation.
-
#delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation cluster.
-
#delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation configuration.
-
#delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation.
-
#generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GenerateAccessTokenResponse
Returns a short-lived credential that can be used to send authenticated and authorized traffic to a workstation.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::WorkstationCluster
Returns the requested workstation cluster.
-
#get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::WorkstationConfig
Returns the requested workstation configuration.
-
#get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Gets the access control policy for a resource.
-
#get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Workstation
Returns the requested workstation.
-
#get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ CloudWorkstationsService
constructor
A new instance of CloudWorkstationsService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListUsableWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster on which the caller has the "workstations.workstation.create" permission.
-
#list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListUsableWorkstationsResponse
Returns all workstations using the specified workstation configuration on which the caller has the "workstations.workstations.use" permission.
-
#list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationsResponse
Returns all Workstations using the specified workstation configuration.
-
#list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster.
-
#list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationClustersResponse
Returns all workstation clusters in the specified location.
-
#patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation cluster.
-
#patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation configuration.
-
#patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation.
-
#set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Sets the access control policy on the specified resource.
-
#set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Sets the access control policy on the specified resource.
-
#start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Starts running a workstation so that users can connect to it.
-
#stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Stops running a workstation, reducing costs.
-
#test_workstation_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_workstation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ CloudWorkstationsService
Returns a new instance of CloudWorkstationsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-workstations_v1beta', client_version: Google::Apis::WorkstationsV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 82 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:cancel', ) command.request_representation = Google::Apis::WorkstationsV1beta::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation cluster.
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 233 def create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/workstationClusters', ) command.request_representation = Google::Apis::WorkstationsV1beta::WorkstationCluster::Representation command.request_object = workstation_cluster_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationClusterId'] = workstation_cluster_id unless workstation_cluster_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation configuration.
431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 431 def create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/workstationConfigs', ) command.request_representation = Google::Apis::WorkstationsV1beta::WorkstationConfig::Representation command.request_object = workstation_config_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationConfigId'] = workstation_config_id unless workstation_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Creates a new workstation.
788 789 790 791 792 793 794 795 796 797 798 799 800 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 788 def create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/workstations', ) command.request_representation = Google::Apis::WorkstationsV1beta::Workstation::Representation command.request_object = workstation_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationId'] = workstation_id unless workstation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
117 118 119 120 121 122 123 124 125 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 117 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::WorkstationsV1beta::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation cluster.
277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 277 def delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation configuration.
475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 475 def delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Deletes the specified workstation.
828 829 830 831 832 833 834 835 836 837 838 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 828 def delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::GenerateAccessTokenResponse
Returns a short-lived credential that can be used to send authenticated and authorized traffic to a workstation. Once generated this token cannot be revoked and is good for the lifetime of the token.
864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 864 def generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+workstation}:generateAccessToken', ) command.request_representation = Google::Apis::WorkstationsV1beta::GenerateAccessTokenRequest::Representation command.request_object = generate_access_token_request_object command.response_representation = Google::Apis::WorkstationsV1beta::GenerateAccessTokenResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::GenerateAccessTokenResponse command.params['workstation'] = workstation unless workstation.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
148 149 150 151 152 153 154 155 156 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 148 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::WorkstationCluster
Returns the requested workstation cluster.
310 311 312 313 314 315 316 317 318 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 310 def get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::WorkstationCluster::Representation command.response_class = Google::Apis::WorkstationsV1beta::WorkstationCluster command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::WorkstationConfig
Returns the requested workstation configuration.
508 509 510 511 512 513 514 515 516 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 508 def get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::WorkstationConfig::Representation command.response_class = Google::Apis::WorkstationsV1beta::WorkstationConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
552 553 554 555 556 557 558 559 560 561 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 552 def get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::WorkstationsV1beta::Policy::Representation command.response_class = Google::Apis::WorkstationsV1beta::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Workstation
Returns the requested workstation.
896 897 898 899 900 901 902 903 904 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 896 def get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1beta::Workstation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Workstation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 940 def get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::WorkstationsV1beta::Policy::Representation command.response_class = Google::Apis::WorkstationsV1beta::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 193 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/operations', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListOperationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListUsableWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster on which the caller has the "workstations.workstation.create" permission.
628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 628 def list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workstationConfigs:listUsable', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListUsableWorkstationConfigsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListUsableWorkstationConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListUsableWorkstationsResponse
Returns all workstations using the specified workstation configuration on which the caller has the "workstations.workstations.use" permission.
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1016 def list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workstations:listUsable', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListUsableWorkstationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListUsableWorkstationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationsResponse
Returns all Workstations using the specified workstation configuration.
978 979 980 981 982 983 984 985 986 987 988 989 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 978 def list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workstations', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListWorkstationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListWorkstationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster.
590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 590 def list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workstationConfigs', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::ListWorkstationClustersResponse
Returns all workstation clusters in the specified location.
347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 347 def list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workstationClusters', ) command.response_representation = Google::Apis::WorkstationsV1beta::ListWorkstationClustersResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::ListWorkstationClustersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation cluster.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 390 def patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1beta::WorkstationCluster::Representation command.request_object = workstation_cluster_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation configuration.
671 672 673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 671 def patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1beta::WorkstationConfig::Representation command.request_object = workstation_config_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Updates an existing workstation.
1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1057 def patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1beta::Workstation::Representation command.request_object = workstation_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
711 712 713 714 715 716 717 718 719 720 721 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 711 def set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::WorkstationsV1beta::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::WorkstationsV1beta::Policy::Representation command.response_class = Google::Apis::WorkstationsV1beta::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1097 def set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::WorkstationsV1beta::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::WorkstationsV1beta::Policy::Representation command.response_class = Google::Apis::WorkstationsV1beta::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Starts running a workstation so that users can connect to it.
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1130 def start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:start', ) command.request_representation = Google::Apis::WorkstationsV1beta::StartWorkstationRequest::Representation command.request_object = start_workstation_request_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::Operation
Stops running a workstation, reducing costs.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1163 def stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:stop', ) command.request_representation = Google::Apis::WorkstationsV1beta::StopWorkstationRequest::Representation command.request_object = stop_workstation_request_object command.response_representation = Google::Apis::WorkstationsV1beta::Operation::Representation command.response_class = Google::Apis::WorkstationsV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workstation_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 750 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::WorkstationsV1beta::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workstation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 |
# File 'lib/google/apis/workstations_v1beta/service.rb', line 1202 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::WorkstationsV1beta::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::WorkstationsV1beta::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |