Class: Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::ListWorkstationConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
Response message for ListWorkstationConfigs.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Unreachable resources.
-
#workstation_configs ⇒ Array<Google::Apis::WorkstationsV1beta::WorkstationConfig>
The requested configs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWorkstationConfigsResponse
constructor
A new instance of ListWorkstationConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWorkstationConfigsResponse
Returns a new instance of ListWorkstationConfigsResponse.
1279 1280 1281 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
1267 1268 1269 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1267 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources.
Corresponds to the JSON property unreachable
1272 1273 1274 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1272 def unreachable @unreachable end |
#workstation_configs ⇒ Array<Google::Apis::WorkstationsV1beta::WorkstationConfig>
The requested configs.
Corresponds to the JSON property workstationConfigs
1277 1278 1279 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1277 def workstation_configs @workstation_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1284 1285 1286 1287 1288 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1284 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @workstation_configs = args[:workstation_configs] if args.key?(:workstation_configs) end |