Class: Google::Apis::WorkstationsV1beta::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Metadata for long-running operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1466
1467
1468
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1432

def api_version
  @api_version
end

#create_timeString

Output only. Time that the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1437

def create_time
  @create_time
end

#end_timeString

Output only. Time that the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1442
1443
1444
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1442

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1448
1449
1450
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1448

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1454
1455
1456
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1454

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1459

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1464
1465
1466
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1464

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1471
1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1471

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end