Class: Google::Apis::WorkstationsV1beta::StopWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for StopWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopWorkstationRequest

Returns a new instance of StopWorkstationRequest.



1949
1950
1951
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1940
1941
1942
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1940

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1946
1947
1948
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1946

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1954
1955
1956
1957
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1954

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end