Class: Google::Apis::WorkstationsV1beta::WorkstationBoostConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Boost configuration for this workstation. This object is populated from the parent workstation configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationBoostConfig

Returns a new instance of WorkstationBoostConfig.



2212
2213
2214
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Boost configuration ID. Corresponds to the JSON property id

Returns:

  • (String)


2203
2204
2205
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2203

def id
  @id
end

#runningBoolean Also known as: running?

Output only. Whether or not the current workstation is actively boosted with this id. Corresponds to the JSON property running

Returns:

  • (Boolean)


2209
2210
2211
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2209

def running
  @running
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2217
2218
2219
2220
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2217

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @running = args[:running] if args.key?(:running)
end