Class: Google::Apis::WorkstationsV1beta::WorkstationGceRegionalPersistentDisk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

A Persistent Directory backed by a Compute Engine regional persistent disk within the workstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationGceRegionalPersistentDisk

Returns a new instance of WorkstationGceRegionalPersistentDisk.



2647
2648
2649
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the persistent directory. Corresponds to the JSON property name

Returns:

  • (String)


2640
2641
2642
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2640

def name
  @name
end

#size_gbFixnum

Required. The desired size of the persistent directory in GB. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


2645
2646
2647
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2645

def size_gb
  @size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2652
2653
2654
2655
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2652

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
end