Class: Google::Apis::WorkstationsV1beta::WorkstationPersistentDirectory
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::WorkstationPersistentDirectory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.
Instance Attribute Summary collapse
-
#mount_path ⇒ String
Optional.
-
#size_gb ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationPersistentDirectory
constructor
A new instance of WorkstationPersistentDirectory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationPersistentDirectory
Returns a new instance of WorkstationPersistentDirectory.
2709 2710 2711 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_path ⇒ String
Optional. The mount path of the persistent directory.
Corresponds to the JSON property mountPath
2701 2702 2703 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2701 def mount_path @mount_path end |
#size_gb ⇒ Fixnum
Optional. Size of the persistent directory in GB. If specified in an update
request, this is the desired size of the directory.
Corresponds to the JSON property sizeGb
2707 2708 2709 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2707 def size_gb @size_gb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2714 2715 2716 2717 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2714 def update!(**args) @mount_path = args[:mount_path] if args.key?(:mount_path) @size_gb = args[:size_gb] if args.key?(:size_gb) end |