Class: Google::Apis::WorkstationsV1beta::Container
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::Container
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A Docker container.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional.
-
#command ⇒ Array<String>
Optional.
-
#env ⇒ Hash<String,String>
Optional.
-
#image ⇒ String
Optional.
-
#run_as_user ⇒ Fixnum
Optional.
-
#working_dir ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Container
constructor
A new instance of Container.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Container
Returns a new instance of Container.
365 366 367 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional. Arguments passed to the entrypoint.
Corresponds to the JSON property args
329 330 331 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 329 def args @args end |
#command ⇒ Array<String>
Optional. If set, overrides the default ENTRYPOINT specified by the image.
Corresponds to the JSON property command
334 335 336 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 334 def command @command end |
#env ⇒ Hash<String,String>
Optional. Environment variables passed to the container's entrypoint.
Corresponds to the JSON property env
339 340 341 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 339 def env @env end |
#image ⇒ String
Optional. A Docker container image that defines a custom environment. Cloud
Workstations provides a number of preconfigured images, but you can create your own
custom container images. If using a private image, the host.gceInstance.
serviceAccount field must be specified in the workstation configuration. If
using a custom container image, the service account must have Artifact
Registry Reader permission to pull the specified image. Otherwise, the image
must be publicly accessible.
Corresponds to the JSON property image
353 354 355 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 353 def image @image end |
#run_as_user ⇒ Fixnum
Optional. If set, overrides the USER specified in the image with the given uid.
Corresponds to the JSON property runAsUser
358 359 360 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 358 def run_as_user @run_as_user end |
#working_dir ⇒ String
Optional. If set, overrides the default DIR specified by the image.
Corresponds to the JSON property workingDir
363 364 365 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 363 def working_dir @working_dir end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 370 def update!(**args) @args = args[:args] if args.key?(:args) @command = args[:command] if args.key?(:command) @env = args[:env] if args.key?(:env) @image = args[:image] if args.key?(:image) @run_as_user = args[:run_as_user] if args.key?(:run_as_user) @working_dir = args[:working_dir] if args.key?(:working_dir) end |