Class: Google::Apis::WorkstationsV1beta::CustomerEncryptionKey
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::CustomerEncryptionKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A customer-managed encryption key (CMEK) for the Compute Engine resources of the associated workstation configuration. Specify the name of your Cloud KMS encryption key and the default service account. We recommend that you use a separate service account and follow Cloud KMS best practices.
Instance Attribute Summary collapse
-
#kms_key ⇒ String
Immutable.
-
#kms_key_service_account ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerEncryptionKey
constructor
A new instance of CustomerEncryptionKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerEncryptionKey
Returns a new instance of CustomerEncryptionKey.
405 406 407 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key ⇒ String
Immutable. The name of the Google Cloud KMS encryption key. For example, "
projects/PROJECT_ID/locations/REGION/keyRings/KEY_RING/cryptoKeys/KEY_NAME".
The key must be in the same region as the workstation configuration.
Corresponds to the JSON property kmsKey
393 394 395 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 393 def kms_key @kms_key end |
#kms_key_service_account ⇒ String
Immutable. The service account to use with the specified KMS key. We recommend
that you use a separate service account and follow KMS best practices. For
more information, see Separation of duties and gcloud kms keys add-iam-policy-binding --member.
Corresponds to the JSON property kmsKeyServiceAccount
403 404 405 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 403 def kms_key_service_account @kms_key_service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
410 411 412 413 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 410 def update!(**args) @kms_key = args[:kms_key] if args.key?(:kms_key) @kms_key_service_account = args[:kms_key_service_account] if args.key?(:kms_key_service_account) end |