Class: Google::Apis::WorkstationsV1beta::GenerateAccessTokenRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for GenerateAccessToken.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateAccessTokenRequest

Returns a new instance of GenerateAccessTokenRequest.



1018
1019
1020
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Desired expiration time of the access token. This value must be at most 24 hours in the future. If a value is not specified, the token's expiration time will be set to a default value of 1 hour in the future. Corresponds to the JSON property expireTime

Returns:

  • (String)


1000
1001
1002
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1000

def expire_time
  @expire_time
end

#portFixnum

Optional. Port for which the access token should be generated. If specified, the generated access token grants access only to the specified port of the workstation. If specified, values must be within the range [1 - 65535]. If not specified, the generated access token grants access to all ports of the workstation. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1009
1010
1011
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1009

def port
  @port
end

#ttlString

Desired lifetime duration of the access token. This value must be at most 24 hours. If a value is not specified, the token's lifetime will be set to a default value of 1 hour. Corresponds to the JSON property ttl

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1016

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1023
1024
1025
1026
1027
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1023

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @port = args[:port] if args.key?(:port)
  @ttl = args[:ttl] if args.key?(:ttl)
end