Class: Google::Apis::WorkstationsV1beta::HttpOptions
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::HttpOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
HTTP options for the running workstations.
Instance Attribute Summary collapse
-
#allowed_unauthenticated_cors_preflight_requests ⇒ Boolean
(also: #allowed_unauthenticated_cors_preflight_requests?)
Optional.
-
#disable_localhost_replacement ⇒ Boolean
(also: #disable_localhost_replacement?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpOptions
constructor
A new instance of HttpOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpOptions
Returns a new instance of HttpOptions.
1104 1105 1106 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_unauthenticated_cors_preflight_requests ⇒ Boolean Also known as: allowed_unauthenticated_cors_preflight_requests?
Optional. By default, the workstations service makes sure that all requests to
the workstation are authenticated. CORS preflight requests do not include
cookies or custom headers, and so are considered unauthenticated and blocked
by the workstations service. Enabling this option allows these unauthenticated
CORS preflight requests through to the workstation, where it becomes the
responsibility of the destination server in the workstation to validate the
request.
Corresponds to the JSON property allowedUnauthenticatedCorsPreflightRequests
1091 1092 1093 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1091 def allowed_unauthenticated_cors_preflight_requests @allowed_unauthenticated_cors_preflight_requests end |
#disable_localhost_replacement ⇒ Boolean Also known as: disable_localhost_replacement?
Optional. By default, the workstations service replaces references to
localhost, 127.0.0.1, and 0.0.0.0 with the workstation's hostname in http
responses from the workstation so that applications under development run
properly on the workstation. This may intefere with some applications, and so
this option allows that behavior to be disabled.
Corresponds to the JSON property disableLocalhostReplacement
1101 1102 1103 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1101 def disable_localhost_replacement @disable_localhost_replacement end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1109 1110 1111 1112 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1109 def update!(**args) @allowed_unauthenticated_cors_preflight_requests = args[:allowed_unauthenticated_cors_preflight_requests] if args.key?(:allowed_unauthenticated_cors_preflight_requests) @disable_localhost_replacement = args[:disable_localhost_replacement] if args.key?(:disable_localhost_replacement) end |