Class: Google::Apis::WorkstationsV1beta::PersistentDirectory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will not update existing workstations and will only take effect on new workstations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersistentDirectory

Returns a new instance of PersistentDirectory.



1512
1513
1514
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gce_hdGoogle::Apis::WorkstationsV1beta::GceHyperdiskBalancedHighAvailability

A Persistent Directory backed by a Compute Engine Hyperdisk Balanced High Availability Disk. This is a high-availability block storage solution that offers a balance between performance and cost for most general-purpose workloads. Corresponds to the JSON property gceHd



1494
1495
1496
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1494

def gce_hd
  @gce_hd
end

#gce_pdGoogle::Apis::WorkstationsV1beta::GceRegionalPersistentDisk

A Persistent Directory backed by a Compute Engine regional persistent disk. The persistent_directories field is repeated, but it may contain only one entry. It creates a persistent disk that mounts to the workstation VM at /home when the session starts and detaches when the session ends. If this field is empty, workstations created with this configuration do not have a persistent home directory. Corresponds to the JSON property gcePd



1505
1506
1507
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1505

def gce_pd
  @gce_pd
end

#mount_pathString

Optional. Location of this directory in the running workstation. Corresponds to the JSON property mountPath

Returns:

  • (String)


1510
1511
1512
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1510

def mount_path
  @mount_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1517
1518
1519
1520
1521
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1517

def update!(**args)
  @gce_hd = args[:gce_hd] if args.key?(:gce_hd)
  @gce_pd = args[:gce_pd] if args.key?(:gce_pd)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
end