Class: Google::Apis::WorkstationsV1beta::PrivateClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::PrivateClusterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
Configuration options for private workstation clusters.
Instance Attribute Summary collapse
-
#allowed_projects ⇒ Array<String>
Optional.
-
#cluster_hostname ⇒ String
Output only.
-
#enable_private_endpoint ⇒ Boolean
(also: #enable_private_endpoint?)
Immutable.
-
#service_attachment_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateClusterConfig
constructor
A new instance of PrivateClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateClusterConfig
Returns a new instance of PrivateClusterConfig.
1628 1629 1630 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_projects ⇒ Array<String>
Optional. Additional projects that are allowed to attach to the workstation
cluster's service attachment. By default, the workstation cluster's project
and the VPC host project (if different) are allowed.
Corresponds to the JSON property allowedProjects
1602 1603 1604 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1602 def allowed_projects @allowed_projects end |
#cluster_hostname ⇒ String
Output only. Hostname for the workstation cluster. This field will be
populated only when private endpoint is enabled. To access workstations in the
workstation cluster, create a new DNS zone mapping this domain name to an
internal IP address and a forwarding rule mapping that address to the service
attachment.
Corresponds to the JSON property clusterHostname
1611 1612 1613 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1611 def cluster_hostname @cluster_hostname end |
#enable_private_endpoint ⇒ Boolean Also known as: enable_private_endpoint?
Immutable. Whether Workstations endpoint is private.
Corresponds to the JSON property enablePrivateEndpoint
1616 1617 1618 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1616 def enable_private_endpoint @enable_private_endpoint end |
#service_attachment_uri ⇒ String
Output only. Service attachment URI for the workstation cluster. The service
attachment is created when private endpoint is enabled. To access workstations
in the workstation cluster, configure access to the managed service using
Private Service Connect.
Corresponds to the JSON property serviceAttachmentUri
1626 1627 1628 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1626 def @service_attachment_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1633 1634 1635 1636 1637 1638 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1633 def update!(**args) @allowed_projects = args[:allowed_projects] if args.key?(:allowed_projects) @cluster_hostname = args[:cluster_hostname] if args.key?(:cluster_hostname) @enable_private_endpoint = args[:enable_private_endpoint] if args.key?(:enable_private_endpoint) @service_attachment_uri = args[:service_attachment_uri] if args.key?(:service_attachment_uri) end |