Class: Google::Apis::WorkstationsV1beta::StartWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::StartWorkstationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
Request message for StartWorkstation.
Instance Attribute Summary collapse
-
#boost_config ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartWorkstationRequest
constructor
A new instance of StartWorkstationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartWorkstationRequest
Returns a new instance of StartWorkstationRequest.
1877 1878 1879 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost_config ⇒ String
Optional. If set, the workstation starts using the boost configuration with
the specified ID.
Corresponds to the JSON property boostConfig
1862 1863 1864 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1862 def boost_config @boost_config end |
#etag ⇒ String
Optional. If set, the request will be rejected if the latest version of the
workstation on the server does not have this ETag.
Corresponds to the JSON property etag
1868 1869 1870 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1868 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, validate the request and preview the result, but do not
actually apply it.
Corresponds to the JSON property validateOnly
1874 1875 1876 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1874 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1882 1883 1884 1885 1886 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1882 def update!(**args) @boost_config = args[:boost_config] if args.key?(:boost_config) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |