Class: Google::Apis::WorkstationsV1beta::StartWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for StartWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartWorkstationRequest

Returns a new instance of StartWorkstationRequest.



1855
1856
1857
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_configString

Optional. If set, the workstation starts using the boost configuration with the specified ID. Corresponds to the JSON property boostConfig

Returns:

  • (String)


1840
1841
1842
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1840

def boost_config
  @boost_config
end

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1846
1847
1848
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1846

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1852
1853
1854
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1852

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1860
1861
1862
1863
1864
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1860

def update!(**args)
  @boost_config = args[:boost_config] if args.key?(:boost_config)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end