Class: Google::Apis::WorkstationsV1beta::StopWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for StopWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopWorkstationRequest

Returns a new instance of StopWorkstationRequest.



1923
1924
1925
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1914

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1920
1921
1922
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1920

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1928
1929
1930
1931
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1928

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end