Class: Google::Apis::WorkstationsV1beta::StopWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for StopWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopWorkstationRequest

Returns a new instance of StopWorkstationRequest.



1864
1865
1866
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1855

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1861
1862
1863
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1861

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1869
1870
1871
1872
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1869

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end