Class: Google::Apis::WorkstationsV1beta::SuspendWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::SuspendWorkstationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
Request message for SuspendWorkstation.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuspendWorkstationRequest
constructor
A new instance of SuspendWorkstationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuspendWorkstationRequest
Returns a new instance of SuspendWorkstationRequest.
1977 1978 1979 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. If set, the request will be rejected if the latest version of the
workstation on the server does not have this ETag.
Corresponds to the JSON property etag
1968 1969 1970 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1968 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, validate the request and preview the result, but do not
actually apply it.
Corresponds to the JSON property validateOnly
1974 1975 1976 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1974 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1982 1983 1984 1985 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1982 def update!(**args) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |