Class: Google::Apis::WorkstationsV1beta::SuspendWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

Request message for SuspendWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuspendWorkstationRequest

Returns a new instance of SuspendWorkstationRequest.



1973
1974
1975
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1964

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1970
1971
1972
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1970

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1978
1979
1980
1981
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1978

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end