Class: Google::Apis::WorkstationsV1beta::Workstation
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::Workstation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A single instance of a developer workstation with its own persistent storage.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#boost_configs ⇒ Array<Google::Apis::WorkstationsV1beta::WorkstationBoostConfig>
Output only.
-
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only.
-
#create_time ⇒ String
Output only.
-
#degraded ⇒ Boolean
(also: #degraded?)
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#env ⇒ Hash<String,String>
Optional.
-
#etag ⇒ String
Optional.
-
#host ⇒ String
Output only.
-
#kms_key ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#runtime_host ⇒ Google::Apis::WorkstationsV1beta::RuntimeHost
Runtime host for the workstation.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#source_workstation ⇒ String
Optional.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workstation
constructor
A new instance of Workstation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workstation
Returns a new instance of Workstation.
2049 2050 2051 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
1922 1923 1924 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1922 def annotations @annotations end |
#boost_configs ⇒ Array<Google::Apis::WorkstationsV1beta::WorkstationBoostConfig>
Output only. List of available boost configuration IDs that this workstation
can be boosted up to.
Corresponds to the JSON property boostConfigs
1928 1929 1930 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1928 def boost_configs @boost_configs end |
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only. Status conditions describing the workstation's current state.
Corresponds to the JSON property conditions
1933 1934 1935 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1933 def conditions @conditions end |
#create_time ⇒ String
Output only. Time when this workstation was created.
Corresponds to the JSON property createTime
1938 1939 1940 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1938 def create_time @create_time end |
#degraded ⇒ Boolean Also known as: degraded?
Output only. Whether this workstation is in degraded mode, in which case it
may require user action to restore full functionality. The conditions field
contains detailed information about the status of the workstation.
Corresponds to the JSON property degraded
1945 1946 1947 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1945 def degraded @degraded end |
#delete_time ⇒ String
Output only. Time when this workstation was soft-deleted.
Corresponds to the JSON property deleteTime
1951 1952 1953 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1951 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human-readable name for this workstation.
Corresponds to the JSON property displayName
1956 1957 1958 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1956 def display_name @display_name end |
#env ⇒ Hash<String,String>
Optional. Environment variables passed to the workstation container's
entrypoint.
Corresponds to the JSON property env
1962 1963 1964 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1962 def env @env end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
1969 1970 1971 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1969 def etag @etag end |
#host ⇒ String
Output only. Host to which clients can send HTTPS traffic that will be
received by the workstation. Authorized traffic will be received to the
workstation as HTTP on port 80. To send traffic to a different port, clients
may prefix the host with the destination port in the format port`-`host.
Corresponds to the JSON property host
1977 1978 1979 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1977 def host @host end |
#kms_key ⇒ String
Output only. The name of the Google Cloud KMS encryption key used to encrypt
this workstation. The KMS key can only be configured in the WorkstationConfig.
The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property kmsKey
1984 1985 1986 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1984 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation and that are also propagated to the
underlying Compute Engine resources.
Corresponds to the JSON property labels
1991 1992 1993 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1991 def labels @labels end |
#name ⇒ String
Identifier. Full name of this workstation.
Corresponds to the JSON property name
1996 1997 1998 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 1996 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation is currently being updated to
match its intended state.
Corresponds to the JSON property reconciling
2002 2003 2004 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2002 def reconciling @reconciling end |
#runtime_host ⇒ Google::Apis::WorkstationsV1beta::RuntimeHost
Runtime host for the workstation.
Corresponds to the JSON property runtimeHost
2008 2009 2010 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2008 def runtime_host @runtime_host end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2013 2014 2015 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2013 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2019 2020 2021 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2019 def satisfies_pzs @satisfies_pzs end |
#source_workstation ⇒ String
Optional. The source workstation from which this workstation's persistent
directories were cloned on creation.
Corresponds to the JSON property sourceWorkstation
2026 2027 2028 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2026 def source_workstation @source_workstation end |
#start_time ⇒ String
Output only. Time when this workstation was most recently successfully started,
regardless of the workstation's initial state.
Corresponds to the JSON property startTime
2032 2033 2034 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2032 def start_time @start_time end |
#state ⇒ String
Output only. Current state of the workstation.
Corresponds to the JSON property state
2037 2038 2039 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2037 def state @state end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation.
Corresponds to the JSON property uid
2042 2043 2044 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2042 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation was most recently updated.
Corresponds to the JSON property updateTime
2047 2048 2049 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2047 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2054 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @boost_configs = args[:boost_configs] if args.key?(:boost_configs) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @degraded = args[:degraded] if args.key?(:degraded) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @env = args[:env] if args.key?(:env) @etag = args[:etag] if args.key?(:etag) @host = args[:host] if args.key?(:host) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @runtime_host = args[:runtime_host] if args.key?(:runtime_host) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @source_workstation = args[:source_workstation] if args.key?(:source_workstation) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |