Class: Google::Apis::WorkstationsV1beta::WorkstationBoostConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::WorkstationBoostConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
Boost configuration for this workstation. This object is populated from the parent workstation configuration.
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#running ⇒ Boolean
(also: #running?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationBoostConfig
constructor
A new instance of WorkstationBoostConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationBoostConfig
Returns a new instance of WorkstationBoostConfig.
2097 2098 2099 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Boost configuration ID.
Corresponds to the JSON property id
2088 2089 2090 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2088 def id @id end |
#running ⇒ Boolean Also known as: running?
Output only. Whether or not the current workstation is actively boosted with
this id.
Corresponds to the JSON property running
2094 2095 2096 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2094 def running @running end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2102 2103 2104 2105 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2102 def update!(**args) @id = args[:id] if args.key?(:id) @running = args[:running] if args.key?(:running) end |