Class: Google::Apis::WorkstationsV1beta::WorkstationCluster
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::WorkstationCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A workstation cluster resource in the Cloud Workstations API. Defines a group of workstations in a particular region and the VPC network they're attached to.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only.
-
#control_plane_ip ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#degraded ⇒ Boolean
(also: #degraded?)
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#domain_config ⇒ Google::Apis::WorkstationsV1beta::DomainConfig
Configuration options for a custom domain.
-
#etag ⇒ String
Optional.
-
#gateway_config ⇒ Google::Apis::WorkstationsV1beta::GatewayConfig
Configuration options for Cluster HTTP Gateway.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Immutable.
-
#private_cluster_config ⇒ Google::Apis::WorkstationsV1beta::PrivateClusterConfig
Configuration options for private workstation clusters.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#subnetwork ⇒ String
Immutable.
-
#tags ⇒ Hash<String,String>
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#workstation_authorization_url ⇒ String
Optional.
-
#workstation_launch_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationCluster
constructor
A new instance of WorkstationCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationCluster
Returns a new instance of WorkstationCluster.
2378 2379 2380 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
2235 2236 2237 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2235 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only. Status conditions describing the workstation cluster's current
state.
Corresponds to the JSON property conditions
2241 2242 2243 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2241 def conditions @conditions end |
#control_plane_ip ⇒ String
Output only. The private IP address of the control plane for this workstation
cluster. Workstation VMs need access to this IP address to work with the
service, so make sure that your firewall rules allow egress from the
workstation VMs to this address.
Corresponds to the JSON property controlPlaneIp
2249 2250 2251 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2249 def control_plane_ip @control_plane_ip end |
#create_time ⇒ String
Output only. Time when this workstation cluster was created.
Corresponds to the JSON property createTime
2254 2255 2256 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2254 def create_time @create_time end |
#degraded ⇒ Boolean Also known as: degraded?
Output only. Whether this workstation cluster is in degraded mode, in which
case it may require user action to restore full functionality. The conditions
field contains detailed information about the status of the cluster.
Corresponds to the JSON property degraded
2261 2262 2263 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2261 def degraded @degraded end |
#delete_time ⇒ String
Output only. Time when this workstation cluster was soft-deleted.
Corresponds to the JSON property deleteTime
2267 2268 2269 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2267 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human-readable name for this workstation cluster.
Corresponds to the JSON property displayName
2272 2273 2274 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2272 def display_name @display_name end |
#domain_config ⇒ Google::Apis::WorkstationsV1beta::DomainConfig
Configuration options for a custom domain.
Corresponds to the JSON property domainConfig
2277 2278 2279 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2277 def domain_config @domain_config end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
2284 2285 2286 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2284 def etag @etag end |
#gateway_config ⇒ Google::Apis::WorkstationsV1beta::GatewayConfig
Configuration options for Cluster HTTP Gateway.
Corresponds to the JSON property gatewayConfig
2289 2290 2291 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2289 def gateway_config @gateway_config end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation cluster and that are also propagated to
the underlying Compute Engine resources.
Corresponds to the JSON property labels
2296 2297 2298 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2296 def labels @labels end |
#name ⇒ String
Identifier. Full name of this workstation cluster.
Corresponds to the JSON property name
2301 2302 2303 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2301 def name @name end |
#network ⇒ String
Immutable. Name of the Compute Engine network in which instances associated
with this workstation cluster will be created.
Corresponds to the JSON property network
2307 2308 2309 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2307 def network @network end |
#private_cluster_config ⇒ Google::Apis::WorkstationsV1beta::PrivateClusterConfig
Configuration options for private workstation clusters.
Corresponds to the JSON property privateClusterConfig
2312 2313 2314 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2312 def private_cluster_config @private_cluster_config end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation cluster is currently being
updated to match its intended state.
Corresponds to the JSON property reconciling
2318 2319 2320 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2318 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2324 2325 2326 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2324 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2330 2331 2332 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2330 def satisfies_pzs @satisfies_pzs end |
#subnetwork ⇒ String
Immutable. Name of the Compute Engine subnetwork in which instances associated
with this workstation cluster will be created. Must be part of the subnetwork
specified for this workstation cluster.
Corresponds to the JSON property subnetwork
2338 2339 2340 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2338 def subnetwork @subnetwork end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
2345 2346 2347 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2345 def @tags end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation cluster.
Corresponds to the JSON property uid
2350 2351 2352 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2350 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation cluster was most recently updated.
Corresponds to the JSON property updateTime
2355 2356 2357 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2355 def update_time @update_time end |
#workstation_authorization_url ⇒ String
Optional. Specifies the redirect URL for unauthorized requests received by
workstation VMs in this cluster. Redirects to this endpoint will send a base64
encoded state query param containing the target workstation name and
original request hostname. The endpoint is responsible for retrieving a token
using GenerateAccessToken and redirecting back to the original hostname with
the token.
Corresponds to the JSON property workstationAuthorizationUrl
2365 2366 2367 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2365 def @workstation_authorization_url end |
#workstation_launch_url ⇒ String
Optional. Specifies the launch URL for workstations in this cluster. Requests
sent to unstarted workstations will be redirected to this URL. Requests
redirected to the launch endpoint will be sent with a workstation and
project query parameter containing the full workstation resource name and
project ID, respectively. The launch endpoint is responsible for starting the
workstation, polling it until it reaches STATE_RUNNING, and then issuing a
redirect to the workstation's host URL.
Corresponds to the JSON property workstationLaunchUrl
2376 2377 2378 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2376 def workstation_launch_url @workstation_launch_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2383 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @control_plane_ip = args[:control_plane_ip] if args.key?(:control_plane_ip) @create_time = args[:create_time] if args.key?(:create_time) @degraded = args[:degraded] if args.key?(:degraded) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @domain_config = args[:domain_config] if args.key?(:domain_config) @etag = args[:etag] if args.key?(:etag) @gateway_config = args[:gateway_config] if args.key?(:gateway_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @private_cluster_config = args[:private_cluster_config] if args.key?(:private_cluster_config) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @tags = args[:tags] if args.key?(:tags) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @workstation_authorization_url = args[:workstation_authorization_url] if args.key?(:workstation_authorization_url) @workstation_launch_url = args[:workstation_launch_url] if args.key?(:workstation_launch_url) end |