Class: Google::Apis::WorkstationsV1beta::WorkstationCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

A workstation cluster resource in the Cloud Workstations API. Defines a group of workstations in a particular region and the VPC network they're attached to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationCluster

Returns a new instance of WorkstationCluster.



2338
2339
2340
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Client-specified annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2195
2196
2197
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2195

def annotations
  @annotations
end

#conditionsArray<Google::Apis::WorkstationsV1beta::Status>

Output only. Status conditions describing the workstation cluster's current state. Corresponds to the JSON property conditions



2201
2202
2203
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2201

def conditions
  @conditions
end

#control_plane_ipString

Output only. The private IP address of the control plane for this workstation cluster. Workstation VMs need access to this IP address to work with the service, so make sure that your firewall rules allow egress from the workstation VMs to this address. Corresponds to the JSON property controlPlaneIp

Returns:

  • (String)


2209
2210
2211
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2209

def control_plane_ip
  @control_plane_ip
end

#create_timeString

Output only. Time when this workstation cluster was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2214
2215
2216
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2214

def create_time
  @create_time
end

#degradedBoolean Also known as: degraded?

Output only. Whether this workstation cluster is in degraded mode, in which case it may require user action to restore full functionality. The conditions field contains detailed information about the status of the cluster. Corresponds to the JSON property degraded

Returns:

  • (Boolean)


2221
2222
2223
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2221

def degraded
  @degraded
end

#delete_timeString

Output only. Time when this workstation cluster was soft-deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2227
2228
2229
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2227

def delete_time
  @delete_time
end

#display_nameString

Optional. Human-readable name for this workstation cluster. Corresponds to the JSON property displayName

Returns:

  • (String)


2232
2233
2234
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2232

def display_name
  @display_name
end

#domain_configGoogle::Apis::WorkstationsV1beta::DomainConfig

Configuration options for a custom domain. Corresponds to the JSON property domainConfig



2237
2238
2239
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2237

def domain_config
  @domain_config
end

#etagString

Optional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2244

def etag
  @etag
end

#gateway_configGoogle::Apis::WorkstationsV1beta::GatewayConfig

Configuration options for Cluster HTTP Gateway. Corresponds to the JSON property gatewayConfig



2249
2250
2251
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2249

def gateway_config
  @gateway_config
end

#labelsHash<String,String>

Optional. Labels that are applied to the workstation cluster and that are also propagated to the underlying Compute Engine resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2256
2257
2258
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2256

def labels
  @labels
end

#nameString

Identifier. Full name of this workstation cluster. Corresponds to the JSON property name

Returns:

  • (String)


2261
2262
2263
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2261

def name
  @name
end

#networkString

Immutable. Name of the Compute Engine network in which instances associated with this workstation cluster will be created. Corresponds to the JSON property network

Returns:

  • (String)


2267
2268
2269
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2267

def network
  @network
end

#private_cluster_configGoogle::Apis::WorkstationsV1beta::PrivateClusterConfig

Configuration options for private workstation clusters. Corresponds to the JSON property privateClusterConfig



2272
2273
2274
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2272

def private_cluster_config
  @private_cluster_config
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether this workstation cluster is currently being updated to match its intended state. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2278
2279
2280
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2278

def reconciling
  @reconciling
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2284
2285
2286
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2284

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2290
2291
2292
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2290

def satisfies_pzs
  @satisfies_pzs
end

#subnetworkString

Immutable. Name of the Compute Engine subnetwork in which instances associated with this workstation cluster will be created. Must be part of the subnetwork specified for this workstation cluster. Corresponds to the JSON property subnetwork

Returns:

  • (String)


2298
2299
2300
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2298

def subnetwork
  @subnetwork
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


2305
2306
2307
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2305

def tags
  @tags
end

#uidString

Output only. A system-assigned unique identifier for this workstation cluster. Corresponds to the JSON property uid

Returns:

  • (String)


2310
2311
2312
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2310

def uid
  @uid
end

#update_timeString

Output only. Time when this workstation cluster was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2315
2316
2317
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2315

def update_time
  @update_time
end

#workstation_authorization_urlString

Optional. Specifies the redirect URL for unauthorized requests received by workstation VMs in this cluster. Redirects to this endpoint will send a base64 encoded state query param containing the target workstation name and original request hostname. The endpoint is responsible for retrieving a token using GenerateAccessToken and redirecting back to the original hostname with the token. Corresponds to the JSON property workstationAuthorizationUrl

Returns:

  • (String)


2325
2326
2327
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2325

def workstation_authorization_url
  @workstation_authorization_url
end

#workstation_launch_urlString

Optional. Specifies the launch URL for workstations in this cluster. Requests sent to unstarted workstations will be redirected to this URL. Requests redirected to the launch endpoint will be sent with a workstation and project query parameter containing the full workstation resource name and project ID, respectively. The launch endpoint is responsible for starting the workstation, polling it until it reaches STATE_RUNNING, and then issuing a redirect to the workstation's host URL. Corresponds to the JSON property workstationLaunchUrl

Returns:

  • (String)


2336
2337
2338
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2336

def workstation_launch_url
  @workstation_launch_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2343

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @conditions = args[:conditions] if args.key?(:conditions)
  @control_plane_ip = args[:control_plane_ip] if args.key?(:control_plane_ip)
  @create_time = args[:create_time] if args.key?(:create_time)
  @degraded = args[:degraded] if args.key?(:degraded)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain_config = args[:domain_config] if args.key?(:domain_config)
  @etag = args[:etag] if args.key?(:etag)
  @gateway_config = args[:gateway_config] if args.key?(:gateway_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @private_cluster_config = args[:private_cluster_config] if args.key?(:private_cluster_config)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @tags = args[:tags] if args.key?(:tags)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workstation_authorization_url = args[:workstation_authorization_url] if args.key?(:workstation_authorization_url)
  @workstation_launch_url = args[:workstation_launch_url] if args.key?(:workstation_launch_url)
end