Class: Google::Apis::WorkstationsV1beta::WorkstationConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1beta::WorkstationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb
Overview
A workstation configuration resource in the Cloud Workstations API. Workstation configurations act as templates for workstations. The workstation configuration defines details such as the workstation virtual machine (VM) instance type, persistent storage, container image defining environment, which IDE or Code Editor to use, and more. Administrators and platform teams can also use Identity and Access Management (IAM) rules to grant access to teams or to individual developers.
Instance Attribute Summary collapse
-
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1beta::PortRange>
Optional.
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only.
-
#container ⇒ Google::Apis::WorkstationsV1beta::Container
A Docker container.
-
#create_time ⇒ String
Output only.
-
#degraded ⇒ Boolean
(also: #degraded?)
Output only.
-
#delete_time ⇒ String
Output only.
-
#disable_tcp_connections ⇒ Boolean
(also: #disable_tcp_connections?)
Optional.
-
#display_name ⇒ String
Optional.
-
#enable_audit_agent ⇒ Boolean
(also: #enable_audit_agent?)
Optional.
-
#enable_pushing_credentials ⇒ Boolean
(also: #enable_pushing_credentials?)
Optional.
-
#encryption_key ⇒ Google::Apis::WorkstationsV1beta::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of the associated workstation configuration.
-
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1beta::EphemeralDirectory>
Optional.
-
#etag ⇒ String
Optional.
-
#grant_workstation_admin_role_on_create ⇒ Boolean
(also: #grant_workstation_admin_role_on_create?)
Optional.
-
#host ⇒ Google::Apis::WorkstationsV1beta::Host
Runtime host for a workstation.
-
#http_options ⇒ Google::Apis::WorkstationsV1beta::HttpOptions
HTTP options for the running workstations.
-
#idle_action ⇒ String
Optional.
-
#idle_timeout ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#max_usable_workstations ⇒ Fixnum
Optional.
-
#name ⇒ String
Identifier.
-
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1beta::PersistentDirectory>
Optional.
-
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1beta::ReadinessCheck>
Optional.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#replica_zones ⇒ Array<String>
Optional.
-
#running_timeout ⇒ String
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationConfig
constructor
A new instance of WorkstationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationConfig
Returns a new instance of WorkstationConfig.
2653 2654 2655 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1beta::PortRange>
Optional. A list of PortRanges specifying single ports or ranges of ports that
are externally accessible in the workstation. Allowed ports must be one of 22,
80, or within range 1024-65535. If not specified defaults to ports 22, 80, and
ports 1024-65535.
Corresponds to the JSON property allowedPorts
2426 2427 2428 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2426 def allowed_ports @allowed_ports end |
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
2431 2432 2433 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2431 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::WorkstationsV1beta::Status>
Output only. Status conditions describing the workstation configuration's
current state.
Corresponds to the JSON property conditions
2437 2438 2439 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2437 def conditions @conditions end |
#container ⇒ Google::Apis::WorkstationsV1beta::Container
A Docker container.
Corresponds to the JSON property container
2442 2443 2444 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2442 def container @container end |
#create_time ⇒ String
Output only. Time when this workstation configuration was created.
Corresponds to the JSON property createTime
2447 2448 2449 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2447 def create_time @create_time end |
#degraded ⇒ Boolean Also known as: degraded?
Output only. Whether this workstation configuration is in degraded mode, in
which case it may require user action to restore full functionality. The
conditions field contains detailed information about the status of the
configuration.
Corresponds to the JSON property degraded
2455 2456 2457 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2455 def degraded @degraded end |
#delete_time ⇒ String
Output only. Time when this workstation configuration was soft-deleted.
Corresponds to the JSON property deleteTime
2461 2462 2463 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2461 def delete_time @delete_time end |
#disable_tcp_connections ⇒ Boolean Also known as: disable_tcp_connections?
Optional. Disables support for plain TCP connections in the workstation. By
default the service supports TCP connections through a websocket relay.
Setting this option to true disables that relay, which prevents the usage of
services that require plain TCP connections, such as SSH. When enabled, all
communication must occur over HTTPS or WSS.
Corresponds to the JSON property disableTcpConnections
2470 2471 2472 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2470 def disable_tcp_connections @disable_tcp_connections end |
#display_name ⇒ String
Optional. Human-readable name for this workstation configuration.
Corresponds to the JSON property displayName
2476 2477 2478 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2476 def display_name @display_name end |
#enable_audit_agent ⇒ Boolean Also known as: enable_audit_agent?
Optional. Whether to enable Linux auditd logging on the workstation. When
enabled, a service_account must also be specified that has roles/logging.
logWriter and roles/monitoring.metricWriter on the project. Operating
system audit logging is distinct from Cloud Audit Logs and Container output logging.
Operating system audit logs are available in the Cloud Logging console by querying: resource.type="gce_instance"
log_name:"/logs/linux-auditd"
Corresponds to the JSON property enableAuditAgent
2489 2490 2491 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2489 def enable_audit_agent @enable_audit_agent end |
#enable_pushing_credentials ⇒ Boolean Also known as: enable_pushing_credentials?
Optional. Enables pushing user provided credentials to Workstations by calling
workstations.pushCredentials. If application_default_credentials are supplied
to pushCredentials, the provided token is returned when tools and applications
running in the user container make a request for Default Application
Credentials. Please note that any credentials supplied are made available to
all users with access to the workstation.
Corresponds to the JSON property enablePushingCredentials
2500 2501 2502 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2500 def enable_pushing_credentials @enable_pushing_credentials end |
#encryption_key ⇒ Google::Apis::WorkstationsV1beta::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of
the associated workstation configuration. Specify the name of your Cloud KMS
encryption key and the default service account. We recommend that you use a
separate service account and follow Cloud KMS best practices.
Corresponds to the JSON property encryptionKey
2510 2511 2512 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2510 def encryption_key @encryption_key end |
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1beta::EphemeralDirectory>
Optional. Ephemeral directories which won't persist across workstation
sessions.
Corresponds to the JSON property ephemeralDirectories
2516 2517 2518 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2516 def ephemeral_directories @ephemeral_directories end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
2523 2524 2525 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2523 def etag @etag end |
#grant_workstation_admin_role_on_create ⇒ Boolean Also known as: grant_workstation_admin_role_on_create?
Optional. Grant creator of a workstation roles/workstations.policyAdmin role
along with roles/workstations.user role on the workstation created by them.
This allows workstation users to share access to either their entire
workstation, or individual ports. Defaults to false.
Corresponds to the JSON property grantWorkstationAdminRoleOnCreate
2531 2532 2533 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2531 def grant_workstation_admin_role_on_create @grant_workstation_admin_role_on_create end |
#host ⇒ Google::Apis::WorkstationsV1beta::Host
Runtime host for a workstation.
Corresponds to the JSON property host
2537 2538 2539 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2537 def host @host end |
#http_options ⇒ Google::Apis::WorkstationsV1beta::HttpOptions
HTTP options for the running workstations.
Corresponds to the JSON property httpOptions
2542 2543 2544 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2542 def @http_options end |
#idle_action ⇒ String
Optional. The action to take when the workstation has been idle for the
duration specified in idle_timeout. Defaults to STOP.
Corresponds to the JSON property idleAction
2548 2549 2550 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2548 def idle_action @idle_action end |
#idle_timeout ⇒ String
Optional. Number of seconds to wait before automatically stopping a
workstation after it last received user traffic. A value of "0s" indicates
that Cloud Workstations VMs created with this configuration should never time
out due to idleness. Provide duration terminated by s for seconds—
for example, "7200s" (2 hours). The default is "1200s" (20 minutes).
Corresponds to the JSON property idleTimeout
2558 2559 2560 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2558 def idle_timeout @idle_timeout end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation configuration and that are also propagated
to the underlying Compute Engine resources.
Corresponds to the JSON property labels
2565 2566 2567 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2565 def labels @labels end |
#max_usable_workstations ⇒ Fixnum
Optional. Maximum number of workstations under this configuration a user can
have workstations.workstation.use permission on. Only enforced on
CreateWorkstation API calls on the user issuing the API request. Can be
overridden by: - granting a user workstations.workstationConfigs.
exemptMaxUsableWorkstationLimit permission, or - having a user with that
permission create a workstation and granting another user workstations.
workstation.use permission on that workstation. If not specified, defaults to
0, which indicates unlimited.
Corresponds to the JSON property maxUsableWorkstations
2577 2578 2579 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2577 def max_usable_workstations @max_usable_workstations end |
#name ⇒ String
Identifier. Full name of this workstation configuration.
Corresponds to the JSON property name
2582 2583 2584 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2582 def name @name end |
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1beta::PersistentDirectory>
Optional. Directories to persist across workstation sessions.
Corresponds to the JSON property persistentDirectories
2587 2588 2589 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2587 def persistent_directories @persistent_directories end |
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1beta::ReadinessCheck>
Optional. Readiness checks to perform when starting a workstation using this
workstation configuration. Mark a workstation as running only after all
specified readiness checks return 200 status codes.
Corresponds to the JSON property readinessChecks
2594 2595 2596 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2594 def readiness_checks @readiness_checks end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation configuration is currently
being updated to match its intended state.
Corresponds to the JSON property reconciling
2600 2601 2602 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2600 def reconciling @reconciling end |
#replica_zones ⇒ Array<String>
Optional. Immutable. Specifies the zones used to replicate the VM and disk
resources within the region. If set, exactly two zones within the workstation
cluster's region must be specified—for example, ['us-central1-a', 'us-
central1-f']. If this field is empty, two default zones within the region are
used. Immutable after the workstation configuration is created.
Corresponds to the JSON property replicaZones
2610 2611 2612 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2610 def replica_zones @replica_zones end |
#running_timeout ⇒ String
Optional. Number of seconds to wait before automatically stopping a
workstation. We recommend that workstations be stopped daily so that security
updates can be applied upon restart. The idle_timeout and running_timeout
fields are independent of each other. Note that the running_timeout field
stops workstations after the specified time, regardless of whether or not the
workstations are idle. Provide duration terminated by s for seconds—for
example, "54000s" (15 hours). Defaults to "43200s" (12 hours). A value of
"0s" indicates that workstations using this configuration should never time
out. If encryption_key is set, it must be greater than "0s" and less than "
86400s" (24 hours). Warning: A value of "0s" indicates that Cloud
Workstations VMs created with this configuration have no maximum running time.
This is strongly discouraged because you incur costs and will not pick up
security updates.
Corresponds to the JSON property runningTimeout
2627 2628 2629 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2627 def running_timeout @running_timeout end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2632 2633 2634 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2632 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2638 2639 2640 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2638 def satisfies_pzs @satisfies_pzs end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation
configuration.
Corresponds to the JSON property uid
2645 2646 2647 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2645 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation configuration was most recently
updated.
Corresponds to the JSON property updateTime
2651 2652 2653 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2651 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2658 def update!(**args) @allowed_ports = args[:allowed_ports] if args.key?(:allowed_ports) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @container = args[:container] if args.key?(:container) @create_time = args[:create_time] if args.key?(:create_time) @degraded = args[:degraded] if args.key?(:degraded) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_tcp_connections = args[:disable_tcp_connections] if args.key?(:disable_tcp_connections) @display_name = args[:display_name] if args.key?(:display_name) @enable_audit_agent = args[:enable_audit_agent] if args.key?(:enable_audit_agent) @enable_pushing_credentials = args[:enable_pushing_credentials] if args.key?(:enable_pushing_credentials) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @ephemeral_directories = args[:ephemeral_directories] if args.key?(:ephemeral_directories) @etag = args[:etag] if args.key?(:etag) @grant_workstation_admin_role_on_create = args[:grant_workstation_admin_role_on_create] if args.key?(:grant_workstation_admin_role_on_create) @host = args[:host] if args.key?(:host) @http_options = args[:http_options] if args.key?(:http_options) @idle_action = args[:idle_action] if args.key?(:idle_action) @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout) @labels = args[:labels] if args.key?(:labels) @max_usable_workstations = args[:max_usable_workstations] if args.key?(:max_usable_workstations) @name = args[:name] if args.key?(:name) @persistent_directories = args[:persistent_directories] if args.key?(:persistent_directories) @readiness_checks = args[:readiness_checks] if args.key?(:readiness_checks) @reconciling = args[:reconciling] if args.key?(:reconciling) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @running_timeout = args[:running_timeout] if args.key?(:running_timeout) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |