Class: Google::Apis::WorkstationsV1beta::WorkstationPersistentDirectory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationPersistentDirectory

Returns a new instance of WorkstationPersistentDirectory.



2705
2706
2707
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pathString

Optional. The mount path of the persistent directory. Corresponds to the JSON property mountPath

Returns:

  • (String)


2697
2698
2699
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2697

def mount_path
  @mount_path
end

#size_gbFixnum

Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


2703
2704
2705
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2703

def size_gb
  @size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2710
2711
2712
2713
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2710

def update!(**args)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
end