Class: Google::Apis::WorkstationsV1beta::WorkstationPersistentDirectory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1beta/classes.rb,
lib/google/apis/workstations_v1beta/representations.rb,
lib/google/apis/workstations_v1beta/representations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationPersistentDirectory

Returns a new instance of WorkstationPersistentDirectory.



2680
2681
2682
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gce_pdGoogle::Apis::WorkstationsV1beta::WorkstationGceRegionalPersistentDisk

A Persistent Directory backed by a Compute Engine regional persistent disk within the workstation. Corresponds to the JSON property gcePd



2667
2668
2669
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2667

def gce_pd
  @gce_pd
end

#mount_pathString

Optional. The mount path of the persistent directory. Corresponds to the JSON property mountPath

Returns:

  • (String)


2672
2673
2674
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2672

def mount_path
  @mount_path
end

#size_gbFixnum

Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


2678
2679
2680
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2678

def size_gb
  @size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2685
2686
2687
2688
2689
# File 'lib/google/apis/workstations_v1beta/classes.rb', line 2685

def update!(**args)
  @gce_pd = args[:gce_pd] if args.key?(:gce_pd)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
end